<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Form Recipients /////////////////////////
// Buttons:
define('FORM_RECIPIENTS_HEADING', "Moun k ap resevwa Fòm Edit");
define('FORM_RECIPIENTS_EDIT_FORM_RECIPIENTS_BTN', "Moun k ap resevwa Fòm Edit");
// Console Text:
define('FORM_RECIPIENTS_FORM_PAGE', "Fòm Page");
define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "Ou ka mete plis pase yon moun k ap resevwa pa separe Imèl yo ak vigil.");
// Popup Messages:
define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "Ekonomize moun k ap resevwa ...");
define('VIEW_FORM_TABLES_HEADING', "View Tablo Fòm");
define('VIEW_FORM_TABLES_BTN', "View Tablo Fòm");
define('VIEW_FORM_TABLES_SELECT_TABLE', "Chwazi yon Tab pou wè");
define('VIEW_FORM_TABLES_FILTER_READ', "Filter Li Mesaj");
?>